gam-config 0.3.155

Canonical multi-front-end parsing and normalization for gam FitConfig
docs.rs failed to build gam-config-0.3.155
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: gam-config-0.3.154